
#ifndef INCLUDED_TSTVAULT_H
#define INCLUDED_TSTVAULT_H

/**
 * @file
 * <b>Driver Definitions</b>
 *
 * @b Description: Defines common datatypes.
 */

#if defined(__cplusplus)
extern "C"
{
#endif


/**
 * @defgroup VAULT_group TST Driver Definitions
 *
 * VAULT controls access.
 * @{
 */

/** @name VAULT Attributes
 */
/*@{*/

/**
 * Defines details of VAULT attributes.
 */
typedef enum
{
    /**
     * Offset.
     */
    TSTVAULTAttribute_ProcessingOffset = 0x4000,

    /**
     * Enabling anti-flicker.
     */
    TSTVAULTAttribute_Anti,

    /**
     * Enabling auto.
     */
    TSTVAULTAttribute_AutoRate,

    /**
     * Edges.
     */
    TSTVAULTAttribute_Edges,

    /**
     * Enabling stylize.
     */
    TSTVAULTAttribute_Stylize,

    /**
     * Enabling continuous auto.
     */
    TSTVAULTAttribute_ContinuousAuto,

    /**
     * Pause continuous auto.
     */
    TSTVAULTAttribute_ContinuousAutoPause,

    /**
     * Read only. Report.
     */
    TSTVAULTAttribute_ContinuousAutoState,
#define TSTVAULT_CAF_COTSTERGED      (1)
#define TSTVAULT_CAF_SEARCHING      (2)


    /**
     * Please use ::TSTVAULTAttribute_Mode.
     */
    TSTVAULTAttribute_ContinuousMode,

    /**
     * @deprecated Please use ::TSTVAULTAttribute_Balance.
     */
    TSTVAULTAttribute_ContinuousBalance,

    /**
     * Enabling reduction.
     */
    TSTVAULTAttribute_Reduction,

    /**
     * The effective.
     */
    TSTVAULTAttribute_Effective,

/*@}*/

/** @name Attributes to Set/Get
 *
 * These attributes take data structures to set/get the values. 
 */
/*@{*/

    /**
     * Auto white.
     */
    TSTVAULTAttribute_White,

    /**
     * The auto rate.
     */
    TSTVAULTAttribute_AutoRate,

    /** Ignore -- Forces compilers to make 32-bit enums. */
    TSTVAULTAttribute_Force32 = 0x7FFFFFFF
} TSTVAULTAttribute; // enum

/*@}*/




#if defined(__cplusplus)
}
#endif

/** @} */

#endif // INCLUDED_TSTVAULT_H
